========
PaperPal
========

Duck tapes Zotero_ and K2pdfopt_ together to create a streamlined literature review
workflow.

.. _Zotero: https://www.zotero.org/
.. _K2pdfopt: http://willus.com/k2pdfopt/
